@@ -171,7 +171,7 @@ class MainController:
 
     def start_scan(self):
         if self._scanCommandThread:
-            if self._scanCommandThread.isAlive():
+            if self._scanCommandThread.is_alive():
                 raise AlreadyScanningException
             self._scanCommandThread = None
         self._scanCommand = ScanCommand(controller=self,
@@ -184,7 +184,7 @@ class MainController:
     def is_scan_command_running(self):
         if not self._scanCommandThread:
             return False
-        return self._scanCommandThread.isAlive()
+        return self._scanCommandThread.is_alive()
 
     def stop_scan(self):
         if self._scanCommand:
